@@ -1,4 +1,5 @@
-package Net::eNom;
+package
+Net::eNom;
 
 use strict;
 use warnings;
@@ -7,6 +8,6 @@ use Any::Moose;
 
 extends 'WWW::eNom';
 
-our $VERSION = 'v1.0.0'; # VERSION
+our $VERSION = 'v1.0.1'; # VERSION
 
 1;
